' -----------------------------------------------
' MainForm.vb
' Author: Alex Nesterov
' -----------------------------------------------

Imports Genetibase.Shared

Imports System
Imports System.ComponentModel
Imports System.Diagnostics
Imports System.Drawing
Imports System.Windows.Forms

Public Class MainForm
    Inherits System.Windows.Forms.Form

#Region " Methods.Private "

	Private Sub PopulateCounterNameListBox(ByVal counter As INuGenCounter, ByVal listBox As ListBox)
		Debug.Assert((Not counter Is Nothing), "counter != null")
		Debug.Assert((Not listBox Is Nothing), "listBox != null")

		If (counter Is Nothing) Then
			Throw New ArgumentNullException("counter")
		End If

		If (listBox Is Nothing) Then
			Throw New ArgumentNullException("listBox")
		End If

		Try
			Dim category As New PerformanceCounterCategory(counter.CategoryName, counter.MachineName)
			Dim instances As String() = category.GetInstanceNames
			Dim counters As PerformanceCounter() = Nothing

			If (instances.Length = 0) Then
				counters = category.GetCounters
			Else
				counters = category.GetCounters(instances(0))
			End If

			Dim names As String() = New String(counters.Length - 1) {}

			Dim nameIndex As Integer = 0
			Do While (nameIndex < counters.Length)
				names(nameIndex) = counters(nameIndex).CounterName
				nameIndex += 1
			Loop

			Array.Sort(names, Comparer.Default)

			listBox.Items.AddRange(names)
		Catch e As Exception
			Debug.WriteLine(String.Format("ERROR: {0}", e.Message))
		End Try
	End Sub

#End Region

#Region " EventHandlers "

    Private Sub graphCounterNameListBox_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles graphCounterNameListBox.SelectedIndexChanged
        Me.NuGenGraphGeneric.Reset()
        Me.NuGenGraphGeneric.CounterName = Me.graphCounterNameListBox.SelectedItem.ToString()
    End Sub

    Private Sub meterCounterNameListBox_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles meterCounterNameListBox.SelectedIndexChanged
        Me.NuGenMeterGeneric.Reset()
        Me.NuGenMeterGeneric.CounterName = Me.meterCounterNameListBox.SelectedItem.ToString()
    End Sub

    Private Sub MainForm_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        Me.PopulateCounterNameListBox(Me.NuGenGraphGeneric, Me.graphCounterNameListBox)
        Me.PopulateCounterNameListBox(Me.NuGenMeterGeneric, Me.meterCounterNameListBox)

        Me.graphCounterNameListBox.SelectedIndex = 0
        Me.meterCounterNameListBox.SelectedIndex = 0
    End Sub

#End Region

#Region " Windows Form Designer generated code "

    Public Sub New()
        MyBase.New()

        'This call is required by the Windows Form Designer.
        InitializeComponent()

        'Add any initialization after the InitializeComponent() call

    End Sub

    'Form overrides dispose to clean up the component list.
    Protected Overloads Overrides Sub Dispose(ByVal disposing As Boolean)
        If disposing Then
            If Not (components Is Nothing) Then
                components.Dispose()
            End If
        End If
        MyBase.Dispose(disposing)
    End Sub

    'Required by the Windows Form Designer
    Private components As System.ComponentModel.IContainer

    'NOTE: The following procedure is required by the Windows Form Designer
    'It can be modified using the Windows Form Designer.  
    'Do not modify it using the code editor.
    Friend WithEvents graphGroupBox As System.Windows.Forms.GroupBox
    Friend WithEvents meterGroupBox As System.Windows.Forms.GroupBox
	Friend WithEvents NuGenGraphGeneric As Genetibase.UI.NuGenMeters.NuGenGraphGeneric
	Friend WithEvents NuGenMeterGeneric As Genetibase.UI.NuGenMeters.NuGenMeterGeneric
    Friend WithEvents graphCounterNameListBox As System.Windows.Forms.ListBox
    Friend WithEvents meterCounterNameListBox As System.Windows.Forms.ListBox
    <System.Diagnostics.DebuggerStepThrough()> Private Sub InitializeComponent()
        Me.graphGroupBox = New System.Windows.Forms.GroupBox
        Me.graphCounterNameListBox = New System.Windows.Forms.ListBox
		Me.NuGenGraphGeneric = New Genetibase.UI.NuGenMeters.NuGenGraphGeneric
        Me.meterGroupBox = New System.Windows.Forms.GroupBox
        Me.meterCounterNameListBox = New System.Windows.Forms.ListBox
		Me.NuGenMeterGeneric = New Genetibase.UI.NuGenMeters.NuGenMeterGeneric
        Me.graphGroupBox.SuspendLayout()
        Me.meterGroupBox.SuspendLayout()
        Me.SuspendLayout()
        '
        'graphGroupBox
        '
        Me.graphGroupBox.Controls.Add(Me.graphCounterNameListBox)
        Me.graphGroupBox.Controls.Add(Me.NuGenGraphGeneric)
        Me.graphGroupBox.FlatStyle = System.Windows.Forms.FlatStyle.System
        Me.graphGroupBox.Location = New System.Drawing.Point(8, 8)
        Me.graphGroupBox.Name = "graphGroupBox"
        Me.graphGroupBox.Size = New System.Drawing.Size(456, 136)
        Me.graphGroupBox.TabIndex = 0
        Me.graphGroupBox.TabStop = False
        Me.graphGroupBox.Text = "Graph"
        '
        'graphCounterNameListBox
        '
        Me.graphCounterNameListBox.IntegralHeight = False
        Me.graphCounterNameListBox.Location = New System.Drawing.Point(264, 24)
        Me.graphCounterNameListBox.Name = "graphCounterNameListBox"
        Me.graphCounterNameListBox.Size = New System.Drawing.Size(184, 104)
        Me.graphCounterNameListBox.TabIndex = 1
        '
        'NuGenGraphGeneric
        '
        Me.NuGenGraphGeneric.CategoryName = "Processor"
        Me.NuGenGraphGeneric.CounterName = "% Processor Time"
        Me.NuGenGraphGeneric.InstanceName = "_Total"
        Me.NuGenGraphGeneric.Location = New System.Drawing.Point(8, 24)
        Me.NuGenGraphGeneric.MachineName = "."
        Me.NuGenGraphGeneric.Name = "NuGenGraphGeneric"
        Me.NuGenGraphGeneric.Size = New System.Drawing.Size(250, 105)
        Me.NuGenGraphGeneric.TabIndex = 0
        '
        'meterGroupBox
        '
        Me.meterGroupBox.Controls.Add(Me.meterCounterNameListBox)
        Me.meterGroupBox.Controls.Add(Me.NuGenMeterGeneric)
        Me.meterGroupBox.FlatStyle = System.Windows.Forms.FlatStyle.System
        Me.meterGroupBox.Location = New System.Drawing.Point(8, 152)
        Me.meterGroupBox.Name = "meterGroupBox"
        Me.meterGroupBox.Size = New System.Drawing.Size(456, 136)
        Me.meterGroupBox.TabIndex = 0
        Me.meterGroupBox.TabStop = False
        Me.meterGroupBox.Text = "Meter"
        '
        'meterCounterNameListBox
        '
        Me.meterCounterNameListBox.IntegralHeight = False
        Me.meterCounterNameListBox.Location = New System.Drawing.Point(264, 16)
        Me.meterCounterNameListBox.Name = "meterCounterNameListBox"
        Me.meterCounterNameListBox.Size = New System.Drawing.Size(184, 112)
        Me.meterCounterNameListBox.TabIndex = 1
        '
        'NuGenMeterGeneric
        '
        Me.NuGenMeterGeneric.CaptionText = "% Processor Time"
        Me.NuGenMeterGeneric.CaptionTextBackColor = System.Drawing.SystemColors.Control
        Me.NuGenMeterGeneric.CaptionTextFont = New System.Drawing.Font("Microsoft Sans Serif", 8.25!, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, CType(204, Byte))
        Me.NuGenMeterGeneric.CaptionTextForeColor = System.Drawing.SystemColors.ControlText
        Me.NuGenMeterGeneric.CategoryName = "Processor"
        Me.NuGenMeterGeneric.CounterFormat = "%"
        Me.NuGenMeterGeneric.CounterName = "% Processor Time"
        Me.NuGenMeterGeneric.InstanceName = "_Total"
        Me.NuGenMeterGeneric.Location = New System.Drawing.Point(8, 24)
        Me.NuGenMeterGeneric.MachineName = "."
        Me.NuGenMeterGeneric.Name = "NuGenMeterGeneric"
        Me.NuGenMeterGeneric.Orientation = Genetibase.Shared.NuGenOrientationStyle.Horizontal
        Me.NuGenMeterGeneric.ProgressTextBackColor = System.Drawing.SystemColors.Control
        Me.NuGenMeterGeneric.ProgressTextBorderColor = System.Drawing.Color.Black
        Me.NuGenMeterGeneric.ProgressTextFont = New System.Drawing.Font("Microsoft Sans Serif", 8.25!, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, CType(204, Byte))
        Me.NuGenMeterGeneric.ProgressTextForeColor = System.Drawing.SystemColors.ControlText
        Me.NuGenMeterGeneric.Size = New System.Drawing.Size(250, 105)
        Me.NuGenMeterGeneric.TabIndex = 0
        '
        'MainForm
        '
        Me.AutoScaleBaseSize = New System.Drawing.Size(5, 13)
        Me.ClientSize = New System.Drawing.Size(474, 296)
        Me.Controls.Add(Me.graphGroupBox)
        Me.Controls.Add(Me.meterGroupBox)
        Me.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedSingle
        Me.Name = "MainForm"
        Me.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen
        Me.Text = "GenericMeters"
        Me.graphGroupBox.ResumeLayout(False)
        Me.meterGroupBox.ResumeLayout(False)
        Me.ResumeLayout(False)

    End Sub

#End Region

End Class
